(v1.9.1)=
### 1.9.1 {small}`2022-04-05`

#### Bug fixes

- {func}`~scanpy.pp.normalize_total` works when Dask is not installed {pr}`2209` {smaller}`R Cannoodt`
- Fix embedding plots by bumping matplotlib dependency to version 3.4 {pr}`2212` {smaller}`I Virshup`
